"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
function parse(str) {
    var json = JSON.parse(str);
    return parseAny(json);
}
exports.parse = parse;
function parseAny(json) {
    if (json.type !== undefined && typeof json.type === "string") {
        if (json.type === "object") {
            if (json.properties !== undefined && _.isPlainObject(json.properties)) {
                var properties = _.mapValues(json.properties, function (v) { return parseAny(v); });
                var title = hasTitle(json) ? json.title : undefined;
                var required = hasRequired(json) ? json.required : undefined;
                return ({ type: "object", title: title, properties: properties, required: required });
            }
            else {
                throw new Error("Missing or empty properties on object definition");
            }
        }
        else if (json.type === "array") {
            if (json.items !== undefined && _.isPlainObject(json.items)) {
                var items = parseAny(json.items);
                return { type: "array", items: items };
            }
            else {
                throw new Error("Missing or empty items on array definition");
            }
        }
        else if (json.type === "string") {
            return ({ type: "string" });
        }
        else if (json.type === "integer") {
            return ({ type: "integer" });
        }
        else if (json.type === "boolean") {
            return ({ type: "boolean" });
        }
        else {
            throw new Error("Unsupported type: " + json.type);
        }
    }
    else {
        throw new Error("Missing type");
    }
}
function hasTitle(json) {
    return (json.title !== undefined && typeof json.title === "string");
}
function hasAnyRequired(json) {
    return (json.required !== undefined && _.isArray(json.required));
}
function hasRequired(json) {
    return hasAnyRequired(json) ? _.every(json.required, function (a) { return (typeof a === "string"); }) : false;
}
