"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function parseJwkSet(json) {
    var obj = JSON.parse(json);
    return unmarshalJwkSet(obj);
}
exports.parseJwkSet = parseJwkSet;
function unmarshalJwkSet(obj) {
    if (obj === undefined || obj === null || typeof obj !== "object") {
        throw new Error("Expected object but actually found " + obj);
    }
    else {
        return {
            keys: unmarshalArray(obj.keys, unmarshalJwk),
        };
    }
}
exports.unmarshalJwkSet = unmarshalJwkSet;
function parseJwk(json) {
    var obj = JSON.parse(json);
    return unmarshalJwk(obj);
}
exports.parseJwk = parseJwk;
function unmarshalJwk(obj) {
    if (obj === undefined || obj === null || typeof obj !== "object") {
        throw new Error("Expected object but actually found " + obj);
    }
    else {
        return {
            alg: unmarshalString(obj.alg),
            e: unmarshalString(obj.e),
            kid: unmarshalString(obj.kid),
            kty: unmarshalString(obj.kty),
            n: unmarshalString(obj.n),
            use: opt(function () { return unmarshalString(obj.use); }),
        };
    }
}
exports.unmarshalJwk = unmarshalJwk;
function unmarshalArray(as, unmarshalT) {
    if (as === undefined || as === null || !Array.isArray(as)) {
        throw new Error("Expected array but actually found " + as);
    }
    else {
        return as.map(function (a) { return unmarshalT(a); });
    }
}
function unmarshalString(a) {
    if (a === undefined || a === null || typeof a !== "string") {
        throw new Error("Expected string but actually found " + a);
    }
    else {
        return a;
    }
}
function unmarshalNumber(a) {
    if (a === undefined || a === null || typeof a !== "number") {
        throw new Error("Expected number but actually found " + a);
    }
    else {
        return a;
    }
}
function unmarshalBoolean(a) {
    if (a === undefined || a === null || typeof a !== "boolean") {
        throw new Error("Expected boolean but actually found " + a);
    }
    else {
        return a;
    }
}
function opt(f) {
    try {
        return f();
    }
    catch (e) {
        return undefined;
    }
}
