"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
function convert(s) {
    function loop(schema) {
        if (schema.type === "object") {
            var lastKey_1 = _.last(_.keys(schema.properties));
            var unsortedProperties = _.map(schema.properties, function (v, k) { return createProperty(schema, v, k, k === lastKey_1); });
            var properties = _.sortBy(unsortedProperties, function (p) { return p.name; });
            var mustacheObj = { title: schema.title, properties: properties };
            var mustacheObjs = _.flatMap(_.values(schema.properties), function (ns) { return loop(ns); });
            return _.concat([mustacheObj], mustacheObjs);
        }
        else if (schema.type === "string") {
            return []; // No more objects, so return empty array.
        }
        else if (schema.type === "integer") {
            return []; // No more objects, so return empty array.
        }
        else if (schema.type === "boolean") {
            return []; // No more objects, so return empty array.
        }
        else if (schema.type === "array") {
            return loop(schema.items);
        }
        else {
            throw new Error("Unsupported JSON Schema type");
        }
    }
    var objects = loop(s);
    return { objects: objects };
}
exports.convert = convert;
function deriveType(v, k) {
    if (v.type === "object") {
        return (v.title === undefined) ? _.capitalize(k) : v.title;
    }
    else if (v.type === "array") {
        return deriveType(v.items, k);
    }
    else if (v.type === "integer") {
        return "number";
    }
    else if (v.type === "string") {
        return "string";
    }
    else if (v.type === "boolean") {
        return "boolean";
    }
    else {
        throw new Error("Unsupported type!");
    }
}
function pascalCase(s) {
    return _.upperFirst(_.camelCase(s));
}
function createProperty(s, v, k, last) {
    return {
        array: (v.type === "array"),
        capitalizedType: pascalCase(deriveType(v, k)),
        last: last,
        name: k,
        object: (v.type === "object"),
        required: (_.findIndex(s.required, function (r) { return r === k; }) !== -1),
        type: deriveType(v, k),
    };
}
